@@ -25,12 +25,16 @@ def upgrade(args):
     helpers.images.umount_rootfs(args)
     helpers.drivers.loadBinderNodes(args)
     if not args.offline:
-        if args.images_path != tools.config.defaults["preinstalled_images_path"]:
+        preinstalled_images_path = tools.config.defaults["preinstalled_images_path"]
+        if args.images_path != preinstalled_images_path:
             helpers.images.get(args)
+        else:
+            logging.info("Upgrade refused because a pre-installed image is detected at {}.".format(preinstalled_images_path))
     helpers.lxc.setup_host_perms(args)
     helpers.lxc.set_lxc_config(args)
     helpers.lxc.make_base_props(args)
     if status != "STOPPED":
         logging.info("Starting container")
         helpers.images.mount_rootfs(args, args.images_path)
+        helpers.protocol.set_aidl_version(args)
         helpers.lxc.start(args)
